package edu.uoc.tfc.sosuna.gestreform.service;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;

import edu.uoc.tfc.sosuna.gestreform.model.Pressupost;

/**
 * Interficie del API de negoci per a gestionar entitats del tipus Pressupost.
 */
public interface PressupostService {

    /**
     * Crear un pressupost.
     * 
     * @param pressupost L'entitat a crear
     * @return L'entitat creada
     */
    ServiceResults<Pressupost> crea(Pressupost pressupost);

    /**
     * Desar el pressupost.
     * 
     * @param pressupost L'entitat a modificar
     * @return L'entitat modificada
     */
    ServiceResults<Pressupost> modifica(Pressupost pressupost);

    /**
     *  Obtenir tots els pressupostos.
     *  
     *  @param Dades de paginacio
     *  @return La llista d'entitats trobades
     */
    ServiceResults<Page<Pressupost>> llista(Pageable pageable);

    /**
     *  Llistat especial de pressupostos #1.
     *  
     *  @param Dades de paginacio
     *  @return La llista d'entitats trobades. [0] = Pressupost, [1] = Client
     */
    ServiceResults<Page<Object[]>> llista_variant_1(Pageable pageable);
    
    /**
     *  Cercar per ID un pressupost.
     *  
     *  @param id El ID de l'entitat
     *  @return L'entitat trobada
     */
    ServiceResults<Pressupost> consulta(Long id);

}
