package edu.uoc.tfc.sosuna.gestreform.service.impl;

import javax.inject.Inject;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import edu.uoc.tfc.sosuna.gestreform.model.Client;
import edu.uoc.tfc.sosuna.gestreform.persistence.dao.ClientDao;
import edu.uoc.tfc.sosuna.gestreform.service.ClientService;
import edu.uoc.tfc.sosuna.gestreform.service.ServiceResults;

/**
 * Implementacio de la API de negoci per a gestionar entitats del tipus Client.
 */
@Service
@Transactional
public class ClientServiceImpl implements ClientService{

    private final Logger log = LoggerFactory.getLogger(ClientServiceImpl.class);
    
    @Inject
    private ClientDao clientDao;
    
    
    /**
     * Crear un client.
     * 
     * @param client L'entitat a crear
     * @return L'entitat creada
     */
    @Override
	public ServiceResults<Client> crea(Client client) {
        log.debug("Creant Client : {}", client);
        client = clientDao.save(client);
        return new ServiceResults<Client>(client);
    }
    
    /**
     * Desar un client.
     * 
     * @param client L'entitat a modificar
     * @return L'entitat modificada
     */
    @Override
	public ServiceResults<Client> modifica(Client client) {
        log.debug("Modificant Client : {}", client);
        client = clientDao.save(client);
        return new ServiceResults<Client>(client);
    }

    /**
     *  Obtenir tots els clients.
     *  
     *  @param pageable Dades de paginacio
     *  @return Llista d'entitats trobades
     */
    @Override
	@Transactional(readOnly = true) 
    public ServiceResults<Page<Client>> llista(Pageable pageable) {
        log.debug("Obtenint tots els Clients");
        Page<Client> result = clientDao.findAll(pageable); 
        return new ServiceResults<Page<Client>>(result);
    }

    /**
     *  Obtenir un client per el ID.
     *
     *  @param id El ID de l'entitat
     *  @return L'entitat trobada
     */
    @Override
	@Transactional(readOnly = true) 
    public ServiceResults<Client> consulta(Long id) {
        log.debug("Obtenint per ID el Client : {}", id);
        Client client = clientDao.findOne(id);
        return new ServiceResults<Client>(client);
    }

}
