package edu.uoc.tfc.sosuna.gestreform.service.impl;

import javax.inject.Inject;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import edu.uoc.tfc.sosuna.gestreform.model.Manobre;
import edu.uoc.tfc.sosuna.gestreform.persistence.dao.ManobreDao;
import edu.uoc.tfc.sosuna.gestreform.service.ManobreService;
import edu.uoc.tfc.sosuna.gestreform.service.ServiceResults;

/**
 * Implementacio de la API de negoci per a gestionar entitats del tipus Manobre.
 */
@Service
@Transactional
public class ManobreServiceImpl implements ManobreService{

    private final Logger log = LoggerFactory.getLogger(ManobreServiceImpl.class);
    
    @Inject
    private ManobreDao manobreDao;
    
    
    /**
     * Crear un manobre.
     * 
     * @param manobre L'entitat a crear
     * @return L'entitat creada
     */
    @Override
	public ServiceResults<Manobre> crea(Manobre manobre) {
        log.debug("Modificant Manobre : {}", manobre);
        manobre = manobreDao.save(manobre);
        return new ServiceResults<Manobre>(manobre);
    }

    /**
     * Desar un manobre.
     * 
     * @param manobre L'entitat a modificar
     * @return L'entitat modificada
     */
    @Override
	public ServiceResults<Manobre> modifica(Manobre manobre) {
        log.debug("Modificant Manobre : {}", manobre);
        manobre = manobreDao.save(manobre);
        return new ServiceResults<Manobre>(manobre);
    }

    /**
     *  Obtenir tots els manobres.
     *  
     *  @param pageable Dades de paginacio
     *  @return Llista d'entitats trobades
     */
    @Override
	@Transactional(readOnly = true) 
    public ServiceResults<Page<Manobre>> llista(Pageable pageable) {
        log.debug("Obtenint tots els Manobres");
        Page<Manobre> result = manobreDao.findAll(pageable); 
        return new ServiceResults<Page<Manobre>>(result);
    }

    /**
     *  Obtenir un manobre per el ID.
     *
     *  @param id El ID de l'entitat
     *  @return L'entitat trobada
     */
    @Override
	@Transactional(readOnly = true) 
    public ServiceResults<Manobre> consulta(Long id) {
        log.debug("Obtenint per ID el Manobre : {}", id);
        Manobre manobre = manobreDao.findOne(id);
        return new ServiceResults<Manobre>(manobre);
    }

}
