package edu.uoc.tfc.sosuna.gestreform.service.impl;

import javax.inject.Inject;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.Assert;

import edu.uoc.tfc.sosuna.gestreform.model.Usuari;
import edu.uoc.tfc.sosuna.gestreform.model.enumeration.PerfilUsuari;
import edu.uoc.tfc.sosuna.gestreform.persistence.dao.UsuariDao;
import edu.uoc.tfc.sosuna.gestreform.service.ServiceResults;
import edu.uoc.tfc.sosuna.gestreform.service.UsuariService;

@Service
@Transactional
public class UsuariServiceImpl implements UsuariService{

    private final Logger log = LoggerFactory.getLogger(UsuariServiceImpl.class);
    
    @Inject
    private UsuariDao usuariDao;
    
    @Override
	public ServiceResults<Usuari> crea(Usuari usuari) {
        log.debug("Creant l'Usuari : {}", usuari);
        usuari = usuariDao.save(usuari);
        return new ServiceResults<Usuari>(usuari);
    }
    
    @Override
	public ServiceResults<Usuari> modifica(Usuari usuari) {
        log.debug("Actualitzant l'Usuari : {}", usuari);
        usuari = usuariDao.save(usuari);
        return new ServiceResults<Usuari>(usuari);
    }

    @Override
	@Transactional(readOnly = true) 
    public ServiceResults<Page<Usuari>> llista(Pageable pageable) {    	
        log.debug("Llegint llista d'Usuaris");
        Page<Usuari> result = usuariDao.findAll(pageable);
        return new ServiceResults<Page<Usuari>>(result);
    }

    @Override
	@Transactional(readOnly = true) 
    public ServiceResults<Page<Usuari>> llistaPerPerfil(String profileId, Pageable pageable) {
        log.debug("Llegint llista d'Usuaris amb perfil: [{}]", profileId);

        Assert.notNull(profileId);
    	PerfilUsuari perfil = PerfilUsuari.valueOf(profileId);
    	Page<Usuari> result = usuariDao.findAllByPerfil(perfil, pageable);
    	
    	return new ServiceResults<Page<Usuari>>(result);
    }
    
    @Override
	@Transactional(readOnly = true) 
    public ServiceResults<Usuari> consulta(Long id) {
        log.debug("Llegint l'Usuari : {}", id);
        Usuari usuari = usuariDao.findOne(id);
        return new ServiceResults<Usuari>(usuari);
    }

    @Override
    public ServiceResults<Usuari> consultaPerNomUsuari(String login) {
        log.debug("Llegint l'Usuari : {}", login);
        Usuari usuari = usuariDao.findOneByNomUsuari(login);
        return new ServiceResults<Usuari>(usuari);
    }
    
}
