package edu.uoc.tfc.sosuna.gestreform.model;


import java.io.Serializable;
import java.util.Objects;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;

/**
 * Aquesta entitat representa a un client de l'empresa.
 * Els comercials ofereixen pressupostos als clientes.
 * Tot pressupost esta associat a un client.
 * 
 * @author sosuna
 */
@Entity
@Table(name = "client")
public class Client implements Serializable {

    private static final long serialVersionUID = 1L;

    @Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    private Long id;

    @NotNull
    @Size(min = 9, max = 9)
    @Column(name = "nif", length = 9, nullable = false)
    private String nif;

    @NotNull
    @Size(min = 1, max = 50)
    @Column(name = "nom", length = 50, nullable = false)
    private String nom;

    @NotNull
    @Size(min = 1, max = 50)
    @Column(name = "cognom_1", length = 50, nullable = false)
    private String cognom1;

    @Size(min = 1, max = 50)
    @Column(name = "cognom_2", length = 50)
    private String cognom2;

    @NotNull
    @Size(min = 1, max = 50)
    @Column(name = "email", length = 50, nullable = false)
    private String email;

    @NotNull
    @Size(min = 1, max = 50)
    @Column(name = "telefon", length = 50, nullable = false)
    private String telefon;

    @NotNull
    @Size(min = 1, max = 1000)
    @Column(name = "adreca", length = 1000, nullable = false)
    private String adreca;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getNif() {
        return nif;
    }

    public void setNif(String nif) {
        this.nif = nif;
    }

    public String getNom() {
        return nom;
    }

    public void setNom(String nom) {
        this.nom = nom;
    }

    public String getCognom1() {
        return cognom1;
    }

    public void setCognom1(String cognom1) {
        this.cognom1 = cognom1;
    }

    public String getCognom2() {
        return cognom2;
    }

    public void setCognom2(String cognom2) {
        this.cognom2 = cognom2;
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public String getTelefon() {
        return telefon;
    }

    public void setTelefon(String telefon) {
        this.telefon = telefon;
    }

    public String getAdreca() {
        return adreca;
    }

    public void setAdreca(String adreca) {
        this.adreca = adreca;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        Client client = (Client) o;
        if(client.id == null || id == null) {
            return false;
        }
        return Objects.equals(id, client.id);
    }

    @Override
    public int hashCode() {
        return Objects.hashCode(id);
    }

    @Override
    public String toString() {
        return "Client{" +
            "id=" + id +
            ", nif='" + nif + "'" +
            ", nom='" + nom + "'" +
            ", cognom1='" + cognom1 + "'" +
            ", cognom2='" + cognom2 + "'" +
            ", email='" + email + "'" +
            ", telefon='" + telefon + "'" +
            ", adreca='" + adreca + "'" +
            '}';
    }
}
