package edu.uoc.tfc.sosuna.gestreform.model;


import java.io.Serializable;
import java.time.LocalDate;
import java.util.HashSet;
import java.util.Objects;
import java.util.Set;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.JoinTable;
import javax.persistence.ManyToMany;
import javax.persistence.ManyToOne;
import javax.persistence.Table;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;

import edu.uoc.tfc.sosuna.gestreform.model.enumeration.EstatPressupost;

/**
 * Aquesta entitat representa un pressupost.
 * Els pressupostos son creats pels comercials, que els ofereixen als clients.
 * Despres els pressupostos son revisats pels gerents, y associats amb manobres
 * que desenvoluparan les tasques. 
 */
@Entity
@Table(name = "pressupost")
public class Pressupost implements Serializable {

    private static final long serialVersionUID = 1L;

    @Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    private Long id;

    @NotNull
    @Column(name = "imprt", nullable = false)
    private Float imprt;

    @NotNull
    @Enumerated(EnumType.STRING)
    @Column(name = "estat", nullable = false)
    private EstatPressupost estat;

    @NotNull
    @Column(name = "data_inici", nullable = false)
    private LocalDate dataInici;

    @Column(name = "data_fi")
    private LocalDate dataFi;

    @NotNull
    @Size(min = 1, max = 1000)
    @Column(name = "descripcio", length = 1000, nullable = false)
    private String descripcio;

    @ManyToOne
    private Client client;

    @ManyToOne
    private Usuari comercial;

    @ManyToMany
    @JoinTable(name = "pressupost_manobre",
               joinColumns = @JoinColumn(name="pressuposts_id", referencedColumnName="ID"),
               inverseJoinColumns = @JoinColumn(name="manobres_id", referencedColumnName="ID"))
    private Set<Manobre> manobres = new HashSet<>();

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Float getImprt() {
        return imprt;
    }

    public void setImprt(Float imprt) {
        this.imprt = imprt;
    }

    public EstatPressupost getEstat() {
        return estat;
    }

    public void setEstat(EstatPressupost estat) {
        this.estat = estat;
    }

    public LocalDate getDataInici() {
        return dataInici;
    }

    public void setDataInici(LocalDate dataInici) {
        this.dataInici = dataInici;
    }

    public LocalDate getDataFi() {
        return dataFi;
    }

    public void setDataFi(LocalDate dataFi) {
        this.dataFi = dataFi;
    }

    public String getDescripcio() {
        return descripcio;
    }

    public void setDescripcio(String descripcio) {
        this.descripcio = descripcio;
    }

    public Client getClient() {
        return client;
    }

    public void setClient(Client client) {
        this.client = client;
    }

    public Usuari getComercial() {
        return comercial;
    }

    public void setComercial(Usuari usuari) {
        this.comercial = usuari;
    }

    public Set<Manobre> getManobres() {
        return manobres;
    }

    public void setManobres(Set<Manobre> manobres) {
        this.manobres = manobres;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        Pressupost pressupost = (Pressupost) o;
        if(pressupost.id == null || id == null) {
            return false;
        }
        return Objects.equals(id, pressupost.id);
    }

    @Override
    public int hashCode() {
        return Objects.hashCode(id);
    }

    @Override
    public String toString() {
        return "Pressupost{" +
            "id=" + id +
            ", import='" + imprt + "'" +
            ", estat='" + estat + "'" +
            ", dataInici='" + dataInici + "'" +
            ", dataFi='" + dataFi + "'" +
            ", descripcio='" + descripcio + "'" +
            '}';
    }
}
