package edu.uoc.tfc.sosuna.gestreform.model;


import java.io.Serializable;
import java.util.Objects;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;

import edu.uoc.tfc.sosuna.gestreform.model.enumeration.PerfilUsuari;

/**
 * Aquesta entitat representa un usuari del sistema, de qualsevol perfil.
 * 
 * @author sosuna
 */
@Entity
@Table(name = "usuari")
public class Usuari implements Serializable {

    private static final long serialVersionUID = 1L;

    @Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    private Long id;

    @NotNull
    @Size(min = 9, max = 9)
    @Column(name = "nif", length = 9, nullable = false)
    private String nif;

    @NotNull
    @Size(min = 1, max = 50)
    @Column(name = "nom", length = 50, nullable = false)
    private String nom;

    @NotNull
    @Size(min = 1, max = 50)
    @Column(name = "cognom_1", length = 50, nullable = false)
    private String cognom1;

    @Size(min = 1, max = 50)
    @Column(name = "cognom_2", length = 50)
    private String cognom2;

    @NotNull
    @Size(min = 1, max = 50)
    @Column(name = "email", length = 50, nullable = false)
    private String email;

    @NotNull
    @Size(min = 1, max = 50)
    @Column(name = "telefon", length = 50, nullable = false)
    private String telefon;

    @NotNull
    @Size(min = 1, max = 50)
    @Column(name = "nom_usuari", length = 50, nullable = false)
    private String nomUsuari;

    @NotNull
    @Size(min = 1, max = 50)
    @Column(name = "contrasenya", length = 50, nullable = false)
    private String contrasenya;

    @NotNull
    @Enumerated(EnumType.STRING)
    @Column(name = "perfil", nullable = false)
    private PerfilUsuari perfil;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getNif() {
        return nif;
    }

    public void setNif(String nif) {
        this.nif = nif;
    }

    public String getNom() {
        return nom;
    }

    public void setNom(String nom) {
        this.nom = nom;
    }

    public String getCognom1() {
        return cognom1;
    }

    public void setCognom1(String cognom1) {
        this.cognom1 = cognom1;
    }

    public String getCognom2() {
        return cognom2;
    }

    public void setCognom2(String cognom2) {
        this.cognom2 = cognom2;
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public String getTelefon() {
        return telefon;
    }

    public void setTelefon(String telefon) {
        this.telefon = telefon;
    }

    public String getNomUsuari() {
        return nomUsuari;
    }

    public void setNomUsuari(String nomUsuari) {
        this.nomUsuari = nomUsuari;
    }

    public String getContrasenya() {
        return contrasenya;
    }

    public void setContrasenya(String contrasenya) {
        this.contrasenya = contrasenya;
    }

    public PerfilUsuari getPerfil() {
        return perfil;
    }

    public void setPerfil(PerfilUsuari perfil) {
        this.perfil = perfil;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        Usuari usuari = (Usuari) o;
        if(usuari.id == null || id == null) {
            return false;
        }
        return Objects.equals(id, usuari.id);
    }

    @Override
    public int hashCode() {
        return Objects.hashCode(id);
    }

    @Override
    public String toString() {
        return "Usuari{" +
            "id=" + id +
            ", nif='" + nif + "'" +
            ", nom='" + nom + "'" +
            ", cognom1='" + cognom1 + "'" +
            ", cognom2='" + cognom2 + "'" +
            ", email='" + email + "'" +
            ", telefon='" + telefon + "'" +
            ", nomUsuari='" + nomUsuari + "'" +
            ", contrasenya='" + contrasenya + "'" +
            ", perfil='" + perfil + "'" +
            '}';
    }
}
