/**
 * Amb aquesta directiva creem un placeholder per a dibuixar missatges d'error generics provinents del servidor 
 */
(function() {
    'use strict';

    var alertError = {
        template: '<div class="alerts" ng-cloak="">' +
                        '<div ng-repeat="alert in $ctrl.alerts" ng-class="[alert.position]">' +
                            '<uib-alert ng-cloak="" type="{{alert.type}}" close="alert.close($ctrl.alerts)"><pre>{{ alert.msg }}</pre></uib-alert>' +
                        '</div>' +
                  '</div>',
        controller: alertErrorController
    };
    
    angular
        .module('gestreformApp')
        .component('alertError', alertError);

    alertErrorController.$inject = ['$scope', 'AlertService', '$rootScope'];

    function alertErrorController ($scope, AlertService, $rootScope) {
        var vm = this;

        vm.alerts = [];

        function addErrorAlert (message, key, data) {
            vm.alerts.push(
                AlertService.add(
                    {
                        type: 'danger',
                        msg: message,
                        timeout: 5000,
                        scoped: true
                    },
                    vm.alerts
                )
            );
        }

        var cleanHttpErrorListener = $rootScope.$on('gestreformApp.httpError', function (event, httpResponse) {
            var i;
            event.stopPropagation();
            switch (httpResponse.status) {
            // Timeout d'acces al servidor
            case 0:
                addErrorAlert('El servidor no respon','');
                break;

            default:
                var errorHeader = httpResponse.headers('X-GestReform-error');
	            var entityKey = httpResponse.headers('X-GestReform-params');
	            if (errorHeader) {
	                var entityName = entityKey;
	                addErrorAlert(errorHeader, errorHeader, {entityName: entityName});
                } else {
                    addErrorAlert(angular.toJson(httpResponse));
                }	            
            }
        });

        $scope.$on('$destroy', function () {
            if(angular.isDefined(cleanHttpErrorListener) && cleanHttpErrorListener !== null){
                cleanHttpErrorListener();
                vm.alerts = [];
            }
        });
    }
})();
