/**
 * Amb aquest servei controlem els permissos de l'usuari per a la realitzacio d'accions a l'aplicacio.
 */
(function() {
    'use strict';

    angular
        .module('gestreformApp')
        .factory('AuthorizationService', AuthorizationService);

    AuthorizationService.$inject = ['$q', 'Account'];

    function AuthorizationService ($q, Account) {
        var _identity,
            _authenticated = false;

        var service = {
            authenticate: authenticate,
            hasAnyProfile: hasAnyProfile,
            identity: identity,
            isAuthenticated: isAuthenticated,
            isIdentityResolved: isIdentityResolved
        };

        return service;

        function authenticate (identity) {
            _identity = identity;
            _authenticated = identity !== null;
        }

        function hasAnyProfile (profiles) {
            if (!_authenticated || !_identity || !_identity.perfil) {
                return false;
            }

            for (var i = 0; i < profiles.length; i++) {
                if (_identity.perfil == profiles[i]) {
                    return true;
                }
            }

            return false;
        }

        function identity (force) {
            var deferred = $q.defer();

            if (force === true) {
                _identity = undefined;
            }

            // Si ja estem autenticats, retornem la identitat cachejada.
            if (angular.isDefined(_identity)) {
                deferred.resolve(_identity);

                return deferred.promise;
            }

            // Si no estem autenticats, preguntem al servidor la nostra identitat.
            Account.get().$promise
                .then(getAccountThen)
                .catch(getAccountCatch);

            return deferred.promise;

            function getAccountThen (account) {
                _identity = account.data;
                _authenticated = true;
                deferred.resolve(_identity);
            }

            function getAccountCatch () {
                _identity = null;
                _authenticated = false;
                deferred.resolve(_identity);
            }
        }

        function isAuthenticated () {
            return _authenticated;
        }

        function isIdentityResolved () {
            return angular.isDefined(_identity);
        }
    }
})();
