/**
 * Gestio a alt nivel de la maquina d'estats de l'aplicacio
 */
(function() {
    'use strict';

    angular
        .module('gestreformApp')
        .factory('stateHandler', stateHandler);

    stateHandler.$inject = ['$rootScope', '$state',  '$window', 'AuthenticationService', 'AuthorizationService', 'ApplicationConstants'];

    function stateHandler($rootScope, $state,  $window, AuthenticationService, AuthorizationService, ApplicationConstants) {
        return {
            initialize: initialize
        };

        function initialize() {
        	// Tornar a l'estat anterior
            $rootScope.back = back;

            
            // Abans de canviar d'estat, verifiquem que l'usuari tingui permis d'acces
            var stateChangeStart = $rootScope.$on('$stateChangeStart', function (event, toState, toStateParams) {
                $rootScope.toState = toState;
                $rootScope.toStateParams = toStateParams;

                if (AuthorizationService.isIdentityResolved()) {
                    AuthenticationService.authorize();
                }                
            });

            // Activitats comuns al canviar a un nou estat
            var stateChangeSuccess = $rootScope.$on('$stateChangeSuccess',  function(event, toState, toParams, fromState, fromParams) {
                // Personalitzem el titol de la pagina
                var titleKey = ApplicationConstants.defaultWindowTitle;
                if (toState.data.pageTitle) {
                    titleKey = toState.data.pageTitle;
                }
                $window.document.title = titleKey;
            });

            $rootScope.$on('$destroy', function () {
                if(angular.isDefined(stateChangeStart) && stateChangeStart !== null){
                    stateChangeStart();
                }
                if(angular.isDefined(stateChangeSuccess) && stateChangeSuccess !== null){
                    stateChangeSuccess();
                }
            });

            function back() {
                if ($state.get($rootScope.previousStateName) === null) {
                	// No hi ha estat previ. Anem a la pagina principal.
                    $state.go('home');
                } else {
                	// Hi ha estat previ. Hi tornem.
                    $state.go($rootScope.previousStateName, $rootScope.previousStateParams);
                }
            }
        }
    }
})();
