(function() {
    'use strict';

    angular
        .module('gestreformApp')
        .controller('PressupostDialogController', PressupostDialogController);

    PressupostDialogController.$inject = ['$scope', '$rootScope', '$stateParams', '$uibModalInstance', 'entity', 'PressupostService', 'ClientService', 'UsuariService', 'ManobreService', 'Account'];

    function PressupostDialogController ($scope, $rootScope, $stateParams, $uibModalInstance, entity, PressupostService, ClientService, UsuariService, ManobreService, Account) {
        var vm = this;
        
        vm.manobres = null;
        
        vm.pressupost = null;
        
        vm.clients = null;
        vm.client = null;
        vm.clientFormattedName = null;
        
        vm.comercials = null;
        vm.comercial = null;
        vm.comercialFormattedName = null;

        vm.userData = null;
        
        
        
        ClientService.query(function(result) {
        	vm.clients = result;
        	pressupostOnChange();
        });
        UsuariService.query({ flavour: "filterByProfile", profile: "COMERCIAL"}, function(result) {
        	vm.comercials = result;
        	pressupostOnChange();
        });
        ManobreService.query(function(result) {
        	vm.manobres = result;
        });

        // WTF?? De vegades una "promise" i de vegades la entity???
        if (entity && entity.$promise) {
        	entity.$promise.then(function(result){
        		initPressupostData(result);
            });
        }
        else if (entity) {
        	initPressupostData(entity);
        }
        else {
        	throw new Error("Error inesperat. Hauriem d'haver rebut l'entitat amb la ruta");
        }
        
        function initPressupostData(pdata) {
        	vm.pressupost = pdata;

        	if (vm.pressupost.id == null ) {
            	vm.pressupost.estat = 'PENDENT';
            	vm.pressupost.manobres = [];
            }
        	
        	pressupostOnChange();
        }
        
        
        Account.get(function(result) {
        	vm.userData = result.data;
        	if (vm.userData.perfil == 'COMERCIAL') {
        		// Els usuaris de tipus comercial solament poden obrir pressupostos associats a si mateixos.
        		vm.pressupost.comercialId = vm.userData.id;
        		pressupostOnChange();
        	}
        });        
        
        vm.load = function(id) {
            PressupostService.get({id : id}, function(result) {
            	console.log("PressupostService.get()");
            	vm.pressupost = result;
            	pressupostOnChange();
            });
        };
        
        // Quan l'usuari digui "si" al modal de confirmacio de canvi d'estat, llavors podem desar les dades 
        var unsubscribe = $rootScope.$on('gestreformApp:confirmStateChange', function(event, newState) {
        	vm.pressupost.estat = newState;
        	vm.save();
        });
        $scope.$on('$destroy', unsubscribe);
        
        var onSaveSuccess = function (result) {
            $scope.$emit('gestreformApp:pressupostUpdate', result);		// Quan es modifiqui un pressupost, que s'actualitzi la taula.
            $uibModalInstance.close(result);
            vm.isSaving = false;
        };
        var onSaveError = function () {
            vm.isSaving = false;
        };
        vm.save = function () {
            vm.isSaving = true;
            if (vm.pressupost.id !== null) {
                PressupostService.update(vm.pressupost, onSaveSuccess, onSaveError);
            } else {
                PressupostService.save(vm.pressupost, onSaveSuccess, onSaveError);
            }
        };
        vm.clear = function() {
            $uibModalInstance.dismiss('cancel');
        };

        vm.datePickerOpenStatus = {};
        vm.datePickerOpenStatus.dataInici = false;
        vm.datePickerOpenStatus.dataFi = false;
        vm.openCalendar = function(date) {
            vm.datePickerOpenStatus[date] = true;
        };
        
        /**
         * Data range: Controlem que en cas d'haver interval complet, la data de fi sigui posterior.
         */        
        vm.dataRange_invalid = false;
        vm.dataRange_onChange = function() {
        	// True si dataInici i dataFi son dates valides, i dataFi es menor que dataInici
        	vm.dataRange_invalid = 
        		(
    				vm.pressupost.dataFi != null 
    				&& vm.pressupost.dataFi.getTime 
    				&& vm.pressupost.dataInici != null
    				&& vm.pressupost.dataInici.getTime
    				&& (vm.pressupost.dataFi.getTime() < vm.pressupost.dataInici.getTime())
				);
        };
        
        vm.estatValueLabelMapping = {
			"PENDENT" : "Pendent",
			"CANCELLAT" : "Cancel·lat",
			"DENEGAT" : "Denegat",
			"EN_PROCES" : "En Procés",
			"FINALITZAT": "Finalitzat"
        };
        
        $rootScope.confirmSelectComercial = function(id) {
        	vm.pressupost.comercialId = id;
        	pressupostOnChange();
        }
        $rootScope.confirmSelectClient = function(id) {
        	vm.pressupost.clientId = id;
        	pressupostOnChange();
        }        
        
        $rootScope.confirmSelectManobres = function() {
        	vm.pressupost.manobres = $rootScope.currentSelectedManobres;
        }
        vm.beforeOpenSelectManobres = function() {
        	$rootScope.currentSelectedManobres = [];
        	
        	for (var i=0; i<vm.pressupost.manobres.length; i++) {
        		$rootScope.currentSelectedManobres.push(vm.pressupost.manobres[i]);
        	}
        }
        
        
        
        // Funcions 
        function pressupostOnChange() {
        	updateClient();
        	updateClientFormattedName();
        	updateComercial();
        	updateComercialFormattedName();
        }
        
        function updateClient() {
        	vm.client = getClient();
        }
        function updateClientFormattedName() {
        	if (vm.client==null) {
        		vm.clientFormattedName = "";
        	}
        	else {
            	vm.clientFormattedName = (vm.client==null? "" : "("+vm.client.nif+") "+vm.client.cognom1+" "+vm.client.cognom2+", "+vm.client.nom+"");
        	}
        }
        function getClient() {
        	if (!vm.pressupost || !vm.pressupost.clientId) {
        		return null;
        	}
        	if (!vm.clients || vm.clients.length==0) {
        		return null;
        	}        	
        	
        	var found = null;
        	for (var i=0; i<vm.clients.length; i++) {
        		if (vm.clients[i].id == vm.pressupost.clientId) {
        			found = vm.clients[i];
        		}
        	}
        	
        	return found;
        }

        function updateComercial() {
        	vm.comercial = getComercial();
        }
        function updateComercialFormattedName() {
        	if (vm.comercial==null) {
        		vm.comercialFormattedName = "";
        	}
        	else {
            	vm.comercialFormattedName = (vm.comercial==null? "" : "("+vm.comercial.nif+") "+vm.comercial.cognom1+" "+vm.comercial.cognom2+", "+vm.comercial.nom+"");
        	}
        }
        function getComercial() {
        	if (!vm.pressupost || !vm.pressupost.comercialId) {
        		return null;
        	}
        	if (!vm.comercials || vm.comercials.length==0) {
        		return null;
        	}        	
        	
        	var found = null;
        	for (var i=0; i<vm.comercials.length; i++) {
        		if (vm.comercials[i].id == vm.pressupost.comercialId) {
        			found = vm.comercials[i];
        		}
        	}
        	
        	return found;
        }
        
    }
})();
