(function() {
    'use strict';

    angular
        .module('gestreformApp')
        .config(stateConfig);

    stateConfig.$inject = ['$stateProvider', 'ApplicationConstants'];

    function stateConfig($stateProvider, ApplicationConstants) {
        $stateProvider
        .state('pressupost', {
            parent: 'forms',
            url: '/pressupost',
            data: {
                profiles: ['COMERCIAL', 'GERENT'],
                pageTitle: 'Pressuposts'
            },
            views: {
                'content@': {
                    templateUrl: ApplicationConstants.gestiotreballWebModuleRoot + '/app/forms/pressupost/pressuposts.html',
                    controller: 'PressupostController',
                    controllerAs: 'vm'
                }
            },
            resolve: {
            }
        })
        .state('pressupost.new', {
            parent: 'pressupost',
            url: '/new',
            data: {
                profiles: ['COMERCIAL', 'GERENT']
            },
            onEnter: ['$stateParams', '$state', '$uibModal', function($stateParams, $state, $uibModal) {
                $uibModal.open({
                    templateUrl: ApplicationConstants.gestiotreballWebModuleRoot + '/app/forms/pressupost/pressupost-dialog.html',
                    controller: 'PressupostDialogController',
                    controllerAs: 'vm',
                    backdrop: 'static',
                    size: 'lg',
                    resolve: {
                        entity: function () {
                            return {
                                id: null,
                                imprt: null,
                                estat: null,
                                dataInici: null,
                                dataFi: null,
                                descripcio: null,
                                clientId: null,
                                comercialId: null,
                                manobres: null
                            };
                        }
                    }
                }).result.then(function() {
                    $state.go('pressupost', null, { reload: true });
                }, function() {
                    $state.go('pressupost');
                });
            }]
        })
        .state('pressupost.new.selectComercial', {
            parent: 'pressupost.new',
            url: '/selectComercial/{currentComercialId}',
            data: {
                profiles: ['GERENT']
            },
            onEnter: ['$stateParams', '$state', '$uibModal', function($stateParams, $state, $uibModal) {
                $uibModal.open({
                    templateUrl: ApplicationConstants.gestiotreballWebModuleRoot + '/app/forms/pressupost/pressupost-select-comercial-dialog.html',
                    controller: 'PressupostSelectComercialDialogController',
                    controllerAs: 'vm',
                    backdrop: 'static',
                    size: 'lg'
                }).result.then(function() {
                	$state.go('^');
                }, function() {
                    $state.go('^');
                });
            }]
        })        
        .state('pressupost.new.selectClient', {
            parent: 'pressupost.new',
            url: '/selectClient/{currentClientId}',
            data: {
                profiles: ['GERENT', 'COMERCIAL']
            },
            onEnter: ['$stateParams', '$state', '$uibModal', function($stateParams, $state, $uibModal) {
                $uibModal.open({
                    templateUrl: ApplicationConstants.gestiotreballWebModuleRoot + '/app/forms/pressupost/pressupost-select-client-dialog.html',
                    controller: 'PressupostSelectClientDialogController',
                    controllerAs: 'vm',
                    backdrop: 'static',
                    size: 'lg'
                }).result.then(function() {
                	$state.go('^');
                }, function() {
                    $state.go('^');
                });
            }]
        })        
        .state('pressupost.new.selectManobres', {
            parent: 'pressupost.new',
            url: '/selectManobres',
            data: {
                profiles: ['GERENT']
            },
            onEnter: ['$stateParams', '$state', '$uibModal', function($stateParams, $state, $uibModal) {
                $uibModal.open({
                    templateUrl: ApplicationConstants.gestiotreballWebModuleRoot + '/app/forms/pressupost/pressupost-select-manobres-dialog.html',
                    controller: 'PressupostSelectManobresDialogController',
                    controllerAs: 'vm',
                    backdrop: 'static',
                    size: 'lg'
                }).result.then(function() {
                	$state.go('^');
                }, function() {
                    $state.go('^');
                });
            }]
        })
        .state('pressupost.edit', {
            parent: 'pressupost',
            url: '/{id}/edit',
            data: {
                profiles: ['COMERCIAL', 'GERENT']
            },
            onEnter: ['$stateParams', '$state', '$uibModal', function($stateParams, $state, $uibModal) {
                $uibModal.open({
                    templateUrl: ApplicationConstants.gestiotreballWebModuleRoot + '/app/forms/pressupost/pressupost-dialog.html',
                    controller: 'PressupostDialogController',
                    controllerAs: 'vm',
                    backdrop: 'static',
                    size: 'lg',
                    resolve: {
                        entity: ['PressupostService', function(PressupostService) {
                            return PressupostService.get({id : $stateParams.id});
                        }]
                    }
                }).result.then(function() {
                    $state.go('pressupost', null, { reload: true });
                }, function() {
                    $state.go('^');
                });
            }]
        })
        .state('pressupost.edit.selectComercial', {
            parent: 'pressupost.edit',
            url: '/selectComercial/{currentComercialId}',
            data: {
                profiles: ['GERENT']
            },
            onEnter: ['$stateParams', '$state', '$uibModal', function($stateParams, $state, $uibModal) {
                $uibModal.open({
                    templateUrl: ApplicationConstants.gestiotreballWebModuleRoot + '/app/forms/pressupost/pressupost-select-comercial-dialog.html',
                    controller: 'PressupostSelectComercialDialogController',
                    controllerAs: 'vm',
                    backdrop: 'static',
                    size: 'lg'
                }).result.then(function() {
                	$state.go('^');
                }, function() {
                    $state.go('^');
                });
            }]
        })
        .state('pressupost.edit.selectManobres', {
            parent: 'pressupost.edit',
            url: '/selectManobres',
            data: {
                profiles: ['GERENT']
            },
            onEnter: ['$stateParams', '$state', '$uibModal', function($stateParams, $state, $uibModal) {
                $uibModal.open({
                    templateUrl: ApplicationConstants.gestiotreballWebModuleRoot + '/app/forms/pressupost/pressupost-select-manobres-dialog.html',
                    controller: 'PressupostSelectManobresDialogController',
                    controllerAs: 'vm',
                    backdrop: 'static',
                    size: 'lg'
                }).result.then(function() {
                	$state.go('^');
                }, function() {
                    $state.go('^');
                });
            }]
        })
        .state('pressupost.edit.confirmStateChange', {
            parent: 'pressupost.edit',
            url: '/confirmStateChange/{newState}',
            data: {
                profiles: ['GERENT','COMERCIAL']
            },
            onEnter: ['$stateParams', '$state', '$uibModal', function($stateParams, $state, $uibModal) {
                $uibModal.open({
                    templateUrl: ApplicationConstants.gestiotreballWebModuleRoot + '/app/forms/pressupost/pressupost-confirm-state-change-dialog.html',
                    controller: 'PressupostConfirmStateChangeDialogController',
                    controllerAs: 'vm',
                    backdrop: 'static',
                    size: 'lg'
                }).result.then(function() {
                	$state.go('^');
                }, function() {
                    $state.go('^');
                });
            }]
        });
    }

})();
