package edu.uoc.tfc.sosuna.gestreform;

import java.util.Arrays;

import javax.annotation.PostConstruct;
import javax.inject.Inject;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.boot.autoconfigure.EnableAutoConfiguration;
import org.springframework.boot.autoconfigure.liquibase.LiquibaseProperties;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.ComponentScan;
import org.springframework.core.env.Environment;

@ComponentScan(basePackages={
		// Packages a analitzar pe a cercar components
		"edu.uoc.tfc.sosuna.gestreform.persistence",
		"edu.uoc.tfc.sosuna.gestreform.service",
		"edu.uoc.tfc.sosuna.gestreform.security",
		"edu.uoc.tfc.sosuna.gestreform.rest",
		"edu.uoc.tfc.sosuna.gestreform.integration"
})
/*
 * Magia de SpringBoot: Autoconfiguracio de caracteristiques del framework segons les llibreries detectades al classpath.
 * 		http://docs.spring.io/spring-boot/docs/current/reference/html/auto-configuration-classes.html
 */
@EnableAutoConfiguration
@EnableConfigurationProperties({ LiquibaseProperties.class })
public class GestReformApp {

    private static final Logger log = LoggerFactory.getLogger(GestReformApp.class);

    // Perfil de desenvolupament
	// De moment es l'unic.
    public static final String SPRING_PROFILE_DEVELOPMENT = "dev";
    
    @Inject
    private Environment env;

    /**
     * Inicialitzacio de l'aplicacio.
     */
    @PostConstruct
    public void initApplication() {
        if (env.getActiveProfiles().length == 0) {
            throw new IllegalStateException("Error de configuracio. No s'esta executant cap perfil.");
        } else {
	        log.info("Executant aplicacio amb el perfil: {}", Arrays.toString(env.getActiveProfiles()));
        }
    }

}
