package edu.uoc.tfc.sosuna.gestreform.rest.config;

import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.http.converter.json.Jackson2ObjectMapperBuilder;

import com.fasterxml.jackson.databind.SerializationFeature;
import com.fasterxml.jackson.datatype.jsr310.JavaTimeModule;

/**
 * Configuracio de la conversio JSON <=> JAVA als serveis REST.
 * @author sosuna
 *
 */
@Configuration
public class JacksonConfiguration {

    @Bean
    Jackson2ObjectMapperBuilder jackson2ObjectMapperBuilder() {
        Jackson2ObjectMapperBuilder builder = new Jackson2ObjectMapperBuilder();
        // Per defecte, Jackson rep i envia els camps de tipus "data" als DTO es transformen a timestamps numerics (java.util.Date.getTime();
        // Desfem aquesta configuracio perque volem les dates en format text "AAAA-MM-DD" (ISO8601).
        // Mes llegible per al debug, i mes facil d'integrar amb els components GUI selectors de data (HTML5 o components AngularJS).
        // 		http://stackoverflow.com/questions/28745557/serialize-java-time-localdate-into-json-using-jackson/31642197#31642197
        builder.featuresToDisable(SerializationFeature.WRITE_DATES_AS_TIMESTAMPS);	
        builder.modulesToInstall(new JavaTimeModule());
        return builder;
    }
}
