package edu.uoc.tfc.sosuna.gestreform.rest.config;

import javax.inject.Inject;
import javax.sql.DataSource;

import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.security.authentication.AuthenticationManager;
import org.springframework.security.oauth2.config.annotation.configurers.ClientDetailsServiceConfigurer;
import org.springframework.security.oauth2.config.annotation.web.configuration.AuthorizationServerConfigurerAdapter;
import org.springframework.security.oauth2.config.annotation.web.configuration.EnableAuthorizationServer;
import org.springframework.security.oauth2.config.annotation.web.configurers.AuthorizationServerEndpointsConfigurer;
import org.springframework.security.oauth2.provider.token.TokenStore;
import org.springframework.security.oauth2.provider.token.store.JdbcTokenStore;

import edu.uoc.tfc.sosuna.gestreform.security.SecurityConstants;

/**
 * https://www.digitalocean.com/community/tutorials/an-introduction-to-oauth-2
 * 
 * @author sosuna
 */
@Configuration
@EnableAuthorizationServer
public class OAuth2AuthorizationServerConfiguration extends AuthorizationServerConfigurerAdapter {

    @Inject
    private DataSource dataSource;
    @Inject
    private AuthenticationManager authenticationManager;

    @Value("${application.security.authentication.oauth.clientId}")
    private String oauthClientId;
    @Value("${application.security.authentication.oauth.secret}")
    private String oauthSecret;
    
    
    @Bean
    public TokenStore tokenStore() {
    	/*
        	https://github.com/spring-projects/spring-security-oauth/blob/master/spring-security-oauth2/src/main/java/org/springframework/security/oauth2/provider/token/store/JdbcTokenStore.java
        	https://github.com/spring-projects/spring-security-oauth/blob/master/spring-security-oauth2/src/test/resources/schema.sql
    	 */
        return new JdbcTokenStore(dataSource);
    }

    /**
     * http://projects.spring.io/spring-security-oauth/docs/oauth2.html
     */
    @Override
    public void configure(AuthorizationServerEndpointsConfigurer endpoints)
            throws Exception {
        endpoints
                .tokenStore(tokenStore())
                .authenticationManager(authenticationManager);
    }

    /**
     * http://projects.spring.io/spring-security-oauth/docs/oauth2.html
     */
    @Override
    public void configure(ClientDetailsServiceConfigurer clients) throws Exception {
        clients
            .inMemory()
            // ClientID i secret, coneguts tant pel client (frontend) com pel servidor (backend)
            // En el futur, probablement voldrem configuracions separades per a cada modul web...
            .withClient(oauthClientId)
            .secret(oauthSecret)
            // Necessaris per a fer GETs i POSTs al API
            .scopes("read", "write")			
            .authorities(SecurityConstants.ADMINISTRADOR, SecurityConstants.COMERCIAL, SecurityConstants.GERENT)	// Tots els rols possibles
            // Autenticacio per transmissio del password de l'usuari que ha de coincidir amb el de UserDetailsService
            .authorizedGrantTypes("password");	
    }
}