package edu.uoc.tfc.sosuna.gestreform.rest.config;


import javax.inject.Inject;

import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.security.authentication.AuthenticationManager;
import org.springframework.security.config.annotation.authentication.builders.AuthenticationManagerBuilder;
import org.springframework.security.config.annotation.web.builders.HttpSecurity;
import org.springframework.security.config.annotation.web.configuration.EnableWebSecurity;
import org.springframework.security.config.annotation.web.configuration.WebSecurityConfigurerAdapter;
import org.springframework.security.config.http.SessionCreationPolicy;
import org.springframework.security.core.userdetails.UserDetailsService;

@Configuration
@EnableWebSecurity		// Habilitem la seguretat basada en la restriccio d'acces per URLs
public class SecurityConfiguration extends WebSecurityConfigurerAdapter {

    @Inject
    private UserDetailsService userDetailsService;

    @Inject
    public void configureGlobal(AuthenticationManagerBuilder auth) throws Exception {
        // Els usuaris es troben emmagatzemats a la BBDD
    	auth.userDetailsService(userDetailsService);
    }

    @Override
    public void configure(HttpSecurity http) throws Exception {
        http
	        // Per defecte SpringBoot configura la autenticacio de tipus HTTP Basic (amb dialeg de login natiu del navegador).
	        // Aqui els recursos web seran publics, i farem servir OAUTH2 per autenticarse a l'hora de fer servir el API REST,
        	// de manera que no la necessitem.
        	.httpBasic().disable()
            // L'estat de l'aplicacio per a cada client que hi accedeix s'emmagatzema al frontend
            // El backend s'encarregara unicament de respondre a peticions al API REST.
            // De manera que mai no farem servir la sessio Java
            // Amb aquesta configuracio ens estalviem els recursos de memoria i proces que suposen les sessions Java, 
            // que normalment es creen automaticament. 
            .sessionManagement().sessionCreationPolicy(SessionCreationPolicy.STATELESS);
    }

    /**
     * Necessitem exposar el AuthenticationManager com a Spring bean per fer-lo servir a {@link OAuth2AuthorizationServerConfiguration}
     */
    @Override
    @Bean
    public AuthenticationManager authenticationManagerBean() throws Exception {
        return super.authenticationManagerBean();
    }

}
