package edu.uoc.tfc.sosuna.gestreform.rest.mapper;

import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import edu.uoc.tfc.sosuna.gestreform.model.Client;
import edu.uoc.tfc.sosuna.gestreform.model.Manobre;
import edu.uoc.tfc.sosuna.gestreform.model.Pressupost;
import edu.uoc.tfc.sosuna.gestreform.model.Usuari;
import edu.uoc.tfc.sosuna.gestreform.rest.dto.ManobreDTO;
import edu.uoc.tfc.sosuna.gestreform.rest.dto.PressupostDTO;

@Component
public class PressupostMapperImpl implements PressupostMapper {

    @Autowired
    private ManobreMapper manobreMapper;

    @Override
    public PressupostDTO pressupostToPressupostDTO(Pressupost pressupost) {
        if ( pressupost == null ) {
            return null;
        }

        PressupostDTO pressupostDTO = new PressupostDTO();

        pressupostDTO.setComercialId( pressupostComercialId( pressupost ) );
        pressupostDTO.setClientId( pressupostClientId( pressupost ) );
        pressupostDTO.setId( pressupost.getId() );
        pressupostDTO.setImprt( pressupost.getImprt() );
        pressupostDTO.setEstat( pressupost.getEstat() );
        pressupostDTO.setDataInici( pressupost.getDataInici() );
        pressupostDTO.setDataFi( pressupost.getDataFi() );
        pressupostDTO.setDescripcio( pressupost.getDescripcio() );
        pressupostDTO.setManobres( manobreSetToManobreDTOSet( pressupost.getManobres() ) );

        return pressupostDTO;
    }

    @Override
    public List<PressupostDTO> pressupostsToPressupostDTOs(List<Pressupost> pressuposts) {
        if ( pressuposts == null ) {
            return null;
        }

        List<PressupostDTO> list = new ArrayList<PressupostDTO>();
        for ( Pressupost pressupost : pressuposts ) {
            list.add( pressupostToPressupostDTO( pressupost ) );
        }

        return list;
    }

    @Override
    public Pressupost pressupostDTOToPressupost(PressupostDTO pressupostDTO) {
        if ( pressupostDTO == null ) {
            return null;
        }

        Pressupost pressupost = new Pressupost();

        pressupost.setComercial( usuariFromId( pressupostDTO.getComercialId() ) );
        pressupost.setClient( clientFromId( pressupostDTO.getClientId() ) );
        pressupost.setId( pressupostDTO.getId() );
        pressupost.setImprt( pressupostDTO.getImprt() );
        pressupost.setEstat( pressupostDTO.getEstat() );
        pressupost.setDataInici( pressupostDTO.getDataInici() );
        pressupost.setDataFi( pressupostDTO.getDataFi() );
        pressupost.setDescripcio( pressupostDTO.getDescripcio() );
        pressupost.setManobres( manobreDTOSetToManobreSet( pressupostDTO.getManobres() ) );

        return pressupost;
    }

    @Override
    public List<Pressupost> pressupostDTOsToPressuposts(List<PressupostDTO> pressupostDTOs) {
        if ( pressupostDTOs == null ) {
            return null;
        }

        List<Pressupost> list = new ArrayList<Pressupost>();
        for ( PressupostDTO pressupostDTO : pressupostDTOs ) {
            list.add( pressupostDTOToPressupost( pressupostDTO ) );
        }

        return list;
    }

    private Long pressupostComercialId(Pressupost pressupost) {

        if ( pressupost == null ) {
            return null;
        }
        Usuari comercial = pressupost.getComercial();
        if ( comercial == null ) {
            return null;
        }
        Long id = comercial.getId();
        if ( id == null ) {
            return null;
        }
        return id;
    }

    private Long pressupostClientId(Pressupost pressupost) {

        if ( pressupost == null ) {
            return null;
        }
        Client client = pressupost.getClient();
        if ( client == null ) {
            return null;
        }
        Long id = client.getId();
        if ( id == null ) {
            return null;
        }
        return id;
    }

    protected Set<ManobreDTO> manobreSetToManobreDTOSet(Set<Manobre> set) {
        if ( set == null ) {
            return null;
        }

        Set<ManobreDTO> set_ = new HashSet<ManobreDTO>();
        for ( Manobre manobre : set ) {
            set_.add( manobreMapper.manobreToManobreDTO( manobre ) );
        }

        return set_;
    }

    protected Set<Manobre> manobreDTOSetToManobreSet(Set<ManobreDTO> set) {
        if ( set == null ) {
            return null;
        }

        Set<Manobre> set_ = new HashSet<Manobre>();
        for ( ManobreDTO manobreDTO : set ) {
            set_.add( manobreMapper.manobreDTOToManobre( manobreDTO ) );
        }

        return set_;
    }
}
