package edu.uoc.tfc.sosuna.gestreform.rest.security;

import java.io.IOException;

import javax.inject.Inject;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.http.HttpHeaders;
import org.springframework.security.core.Authentication;
import org.springframework.security.oauth2.common.OAuth2AccessToken;
import org.springframework.security.oauth2.provider.token.TokenStore;
import org.springframework.security.web.authentication.AbstractAuthenticationTargetUrlRequestHandler;
import org.springframework.security.web.authentication.logout.LogoutSuccessHandler;
import org.springframework.stereotype.Component;

/**
 * Gestio del logout per Spring Security 
 * TODO: Perque dimonis no hi ha ja una classe de Spring per fer aixo?? Investigar!
 * 		http://forum.spring.io/forum/spring-projects/security/oauth/107820-how-to-invalidate-existing-access-refresh-token-when-logout
 * 		
 */
@Component
public class OAuth2LogoutHandler 
	extends AbstractAuthenticationTargetUrlRequestHandler
    implements LogoutSuccessHandler 
{

    private static final String PREFIX_HEADER_BEARER = "Bearer ";

    @Inject
    private TokenStore tokenStore;

    @Override
    public void onLogoutSuccess(HttpServletRequest request, HttpServletResponse response,
        Authentication authentication)
        throws IOException, ServletException {

        String bearer = extractBearerTokenFromHeader(request);
        
        if (bearer!=null) {
        	OAuth2AccessToken oAuth2AccessToken = tokenStore.readAccessToken(bearer);
            if (oAuth2AccessToken != null) {
                tokenStore.removeAccessToken(oAuth2AccessToken);
            }
        }

        response.setStatus(HttpServletResponse.SC_OK);
    }
    
    private String extractBearerTokenFromHeader(HttpServletRequest request) {
    	// Contingut header de tipus: [Bearer xxxxxxxxxx]
        String token = request.getHeader(HttpHeaders.AUTHORIZATION);
    	
    	if (token != null && token.startsWith(PREFIX_HEADER_BEARER)) {
    		return token.substring(PREFIX_HEADER_BEARER.length());
        }
    	else {
    		return null;
    	}
    }

}
