package edu.uoc.tfc.sosuna.gestreform.rest.service;

import javax.inject.Inject;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import edu.uoc.tfc.sosuna.gestreform.model.Usuari;
import edu.uoc.tfc.sosuna.gestreform.rest.config.RestApiConstants;
import edu.uoc.tfc.sosuna.gestreform.rest.dto.AccountDTO;
import edu.uoc.tfc.sosuna.gestreform.security.SecurityUtils;
import edu.uoc.tfc.sosuna.gestreform.service.ServiceResults;
import edu.uoc.tfc.sosuna.gestreform.service.UsuariService;

/**
 * REST endpoint per la gestio del compte de l'usuari autenticat
 */
@RestController
@RequestMapping(RestApiConstants.API_ROOT)
public class AccountRestResource {

    private final Logger log = LoggerFactory.getLogger(AccountRestResource.class);

    @Inject
    private UsuariService usuariService;
    
    /**
     * GET  /account : Obtenir les dades de l'usuari autenticat
     *
     * @return 
     * 	- Http Status 200 (OK) : Hi ha un usuari autenticat associat a aquesta peticio. Al cos s'envien les dades de l'usuari.
     *  - Http Status 500 (Internal Server Error) : 
     *  		No hi ha usuari autenticat associat. No hauria de passar. 
     *  		Aquest endpoint esta protegit contra accessos no autenticats, de manera que accedir-hi hauria de donar un 401 (Forbidden)  
     */
    @RequestMapping(value = "/account",
        method = RequestMethod.GET,
        produces = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<AccountDTO> consulta() {
    	log.debug("Consultant les dades de l'usuari actual ...");
    	
    	String login = SecurityUtils.getCurrentUserLogin();
    	log.debug("Usuari actual: [{}]", login);
    	
    	Usuari u = null;
    	if (login!=null) {
    		ServiceResults<Usuari> sr = usuariService.consultaPerNomUsuari(login);
    		u = sr.getResultData();
    	}    	
    	
    	if (u==null) {
    		return new ResponseEntity<>(HttpStatus.INTERNAL_SERVER_ERROR);
    	}
    	
    	AccountDTO t = new AccountDTO(u);
    	return new ResponseEntity<>(t, HttpStatus.OK);
    }

}
