package edu.uoc.tfc.sosuna.gestreform.rest.util;

import java.util.Collection;

import org.springframework.http.HttpHeaders;

import edu.uoc.tfc.sosuna.gestreform.service.ServiceMessage;
import edu.uoc.tfc.sosuna.gestreform.service.ServiceResults;

/**
 * Metodes utilitaris per a enviar missatges d'avis o error a la GUI web
 * mitjancant capcaleres HTTP especials.
 */
public class NotificationHeadersUtil {

    public static HttpHeaders createMessage(String message, String param) {
        HttpHeaders headers = new HttpHeaders();
        addMessage(headers, message, param);
        return headers;
    }
    public static HttpHeaders createWarning(String message, String param) {
        HttpHeaders headers = new HttpHeaders();
        addWarning(headers, message, param);
        return headers;
    }
	public static HttpHeaders createError(String message, String param) {
        HttpHeaders headers = new HttpHeaders();
        addError(headers, message, param);
        return headers;
    }
    
    public static HttpHeaders createEntityCreationMessage(String entityName, String param) {
    	HttpHeaders headers = new HttpHeaders();
    	addMessage(headers, "S'ha creat un nou " + entityName + " amb ID: " + param, param);
    	return headers;
    }

    public static HttpHeaders createEntityUpdateMessage(String entityName, String param) {
    	HttpHeaders headers = new HttpHeaders();
    	addMessage(headers, "Actualitzat el " + entityName + " amb ID: " + param, param);
    	return headers;
    }

    private static void addError(HttpHeaders headers, String message, String param) {
        headers.add("X-GestReform-error", message);
        headers.add("X-GestReform-params", param);
    }

    private static void addWarning(HttpHeaders headers, String message, String param) {
        headers.add("X-GestReform-warning", message);
        headers.add("X-GestReform-params", param);
	}

    private static void addMessage(HttpHeaders headers, String message, String param) {
        headers.add("X-GestReform-message", message);
        headers.add("X-GestReform-params", param);
	}
    
    public static void addServiceMessageHeaders(HttpHeaders headers, ServiceResults<?> serviceResults) {
    	if (serviceResults.hasMessages()) {
    		addServiceMessageHeaders(headers, serviceResults.getMessages(), 0);
    	}
    	if (serviceResults.hasWarnings()) {
    		addServiceMessageHeaders(headers, serviceResults.getWarnings(), 1);
    	}
    	if (serviceResults.hasErrors()) {
    		addServiceMessageHeaders(headers, serviceResults.getErrors(), 2);
    	}
    }

    private static void addServiceMessageHeaders(HttpHeaders headers, Collection<ServiceMessage> serviceMessages, int type) {
    	if (serviceMessages==null) {
    		return;
    	}
    	
    	for (ServiceMessage m : serviceMessages) {
    		addServiceMessageHeader(headers, m, type);
    	}
    }
    
    private static void addServiceMessageHeader(HttpHeaders headers, ServiceMessage serviceMessage, int type) {
    	String message = buildMessage(serviceMessage);
    	String param = buildParam(serviceMessage);
    	
    	switch(type) {
    	case 0:
    		addMessage(headers, message, param);
    		break;
    	case 1:
    		addWarning(headers, message, param);
    		break;
    	case 2:
    		addError(headers, message, param);
    		break;
    	default:
    		throw new IllegalArgumentException("type: desconegut");
    	}
    }
    
	private static String buildParam(ServiceMessage serviceMessage) {
		StringBuilder sb = new StringBuilder();
		
		if (serviceMessage.getArguments()!=null) {
			boolean first = true;
			for (Object obj : serviceMessage.getArguments()) {
				if (obj==null) {
					obj="";
				}
				
				if (first) {
					first = false;
				}
				else {
					sb.append("|");
				}
				
				sb.append(obj.toString());
			}
		}
		
		return sb.toString();
	}

	private static String buildMessage(ServiceMessage serviceMessage) {
		return serviceMessage.getMessage();
	}

	public static HttpHeaders createServiceMessageHeaders(ServiceResults<?> sr) {
		HttpHeaders headers = new HttpHeaders();
		addServiceMessageHeaders(headers, sr);
		return headers;
	}
	
}
