package edu.uoc.tfc.sosuna.gestreform.security;

import java.util.Collection;

import org.springframework.security.core.Authentication;
import org.springframework.security.core.GrantedAuthority;
import org.springframework.security.core.authority.SimpleGrantedAuthority;
import org.springframework.security.core.context.SecurityContext;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.security.core.userdetails.UserDetails;

/**
 * Amb aquesta classe interposem una abstraccio entre l'aplicacio i Spring Security.
 */
public final class SecurityUtils {

    /**
     * Obte el login de l'usuari autenticat actual.
     *
     * @return El login de l'usuari
     */
    public static String getCurrentUserLogin() {
        SecurityContext securityContext = SecurityContextHolder.getContext();
        Authentication authentication = securityContext.getAuthentication();
        String userName = null;
        if (authentication != null) {
            if (authentication.getPrincipal() instanceof UserDetails) {
                UserDetails springSecurityUser = (UserDetails) authentication.getPrincipal();
                userName = springSecurityUser.getUsername();
            } else if (authentication.getPrincipal() instanceof String) {
                userName = (String) authentication.getPrincipal();
            }
        }
        return userName;
    }

    /**
     * Comprova si hi ha usuari autenticat 
     *
     * @return true Si hi ha usuari autenticat
     */
    public static boolean isAuthenticated() {
        SecurityContext securityContext = SecurityContextHolder.getContext();
        
        Authentication auth = securityContext.getAuthentication();
        if (auth==null) {
        	return false;
        }
        
        Collection<? extends GrantedAuthority> authorities = auth.getAuthorities();
        return authorities.size()>0;
    }

    /**
     * Comprova si l'usuari actual te aquest perfil.
     *
     * @param profile El perfil a verificar
     * @return true Si l'usuari actual te aquest perfil, altarment false
     */
    public static boolean currentUserHasProfile(String profile) {
        SecurityContext securityContext = SecurityContextHolder.getContext();
        Authentication authentication = securityContext.getAuthentication();
        if (authentication != null) {
            if (authentication.getPrincipal() instanceof UserDetails) {
                UserDetails springSecurityUser = (UserDetails) authentication.getPrincipal();
                return springSecurityUser.getAuthorities().contains(new SimpleGrantedAuthority(profile));
            }
        }
        return false;
    }
}
