package edu.uoc.tfc.sosuna.gestreform.security;

import java.util.ArrayList;
import java.util.List;

import javax.inject.Inject;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.security.core.GrantedAuthority;
import org.springframework.security.core.authority.SimpleGrantedAuthority;
import org.springframework.security.core.userdetails.UserDetails;
import org.springframework.security.core.userdetails.UsernameNotFoundException;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import edu.uoc.tfc.sosuna.gestreform.model.Usuari;
import edu.uoc.tfc.sosuna.gestreform.persistence.dao.UsuariDao;

/**
 * Implementacio del repositori d'usuaris del sistema disponibles per a SpringSecurity.
 */
@Component
public class UserDetailsService implements org.springframework.security.core.userdetails.UserDetailsService {

    private final Logger log = LoggerFactory.getLogger(UserDetailsService.class);

    @Inject
    private UsuariDao usuariDao;

    @Override
    @Transactional
    public UserDetails loadUserByUsername(final String login) {
        log.debug("Carregant l'usuari: [{}]", login);
        String lowercaseLogin = login.toLowerCase();
        
        Usuari user = usuariDao.findOneByNomUsuari(lowercaseLogin);
        
        if (user==null) {
        	throw new UsernameNotFoundException("L'usuari [" + lowercaseLogin + "] no existeix");
        }
        else {
        	List<GrantedAuthority> rols = new ArrayList<>();
        	rols.add(new SimpleGrantedAuthority(user.getPerfil().name()));
        	
        	return new org.springframework.security.core.userdetails.User(
        			lowercaseLogin,
        			user.getContrasenya(),
                    rols);
        }
        
    }
}
